#[repr(C)]pub struct Usb3Payload {
pub b_hub_hdr_dec_lat: u8,
pub w_hub_delay: u16,
pub device_removable: u16,
}Fields
b_hub_hdr_dec_lat: u8w_hub_delay: u16device_removable: u16Trait Implementations
Sourceimpl Clone for Usb3Payload
impl Clone for Usb3Payload
Sourcefn clone(&self) -> Usb3Payload
fn clone(&self) -> Usb3Payload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Usb3Payload
Sourceimpl Debug for Usb3Payload
impl Debug for Usb3Payload
Sourceimpl<D> Decode<Usb3Payload, D> for Usb3Payloadwhere
D: ResourceDialect,
impl<D> Decode<Usb3Payload, D> for Usb3Payloadwhere
D: ResourceDialect,
Sourcefn new_empty() -> Usb3Payload
fn new_empty() -> Usb3Payload
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<Usb3Payload, D> for &Usb3Payloadwhere
D: ResourceDialect,
impl<D> Encode<Usb3Payload, D> for &Usb3Payloadwhere
D: ResourceDialect,
impl Eq for Usb3Payload
Sourceimpl Hash for Usb3Payload
impl Hash for Usb3Payload
Sourceimpl Ord for Usb3Payload
impl Ord for Usb3Payload
Sourcefn cmp(&self, other: &Usb3Payload) -> Ordering
fn cmp(&self, other: &Usb3Payload) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Usb3Payload
impl PartialEq for Usb3Payload
Sourcefn eq(&self, other: &Usb3Payload) -> bool
fn eq(&self, other: &Usb3Payload) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for Usb3Payload
impl PartialOrd for Usb3Payload
impl Persistable for Usb3Payload
impl StructuralPartialEq for Usb3Payload
Sourceimpl TypeMarker for Usb3Payload
impl TypeMarker for Usb3Payload
Sourcetype Owned = Usb3Payload
type Owned = Usb3Payload
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Usb3Payload
impl ValueTypeMarker for Usb3Payload
Sourcetype Borrowed<'a> = &'a Usb3Payload
type Borrowed<'a> = &'a Usb3Payload
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<Usb3Payload as TypeMarker>::Owned,
) -> <Usb3Payload as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<Usb3Payload as TypeMarker>::Owned, ) -> <Usb3Payload as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for Usb3Payload
impl RefUnwindSafe for Usb3Payload
impl Send for Usb3Payload
impl Sync for Usb3Payload
impl Unpin for Usb3Payload
impl UnsafeUnpin for Usb3Payload
impl UnwindSafe for Usb3Payload