#[repr(C)]pub struct UsbInterfaceDescriptor {
pub b_length: u8,
pub b_descriptor_type: u8,
pub b_interface_number: u8,
pub b_alternate_setting: u8,
pub b_num_endpoints: u8,
pub b_interface_class: u8,
pub b_interface_sub_class: u8,
pub b_interface_protocol: u8,
pub i_interface: u8,
}Fields
b_length: u8b_descriptor_type: u8b_interface_number: u8b_alternate_setting: u8b_num_endpoints: u8b_interface_class: u8b_interface_sub_class: u8b_interface_protocol: u8i_interface: u8Trait Implementations
Sourceimpl Clone for UsbInterfaceDescriptor
impl Clone for UsbInterfaceDescriptor
Sourcefn clone(&self) -> UsbInterfaceDescriptor
fn clone(&self) -> UsbInterfaceDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbInterfaceDescriptor
Sourceimpl Debug for UsbInterfaceDescriptor
impl Debug for UsbInterfaceDescriptor
Sourceimpl<D> Decode<UsbInterfaceDescriptor, D> for UsbInterfaceDescriptorwhere
D: ResourceDialect,
impl<D> Decode<UsbInterfaceDescriptor, D> for UsbInterfaceDescriptorwhere
D: ResourceDialect,
Sourcefn new_empty() -> UsbInterfaceDescriptor
fn new_empty() -> UsbInterfaceDescriptor
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<UsbInterfaceDescriptor, D> for &UsbInterfaceDescriptorwhere
D: ResourceDialect,
impl<D> Encode<UsbInterfaceDescriptor, D> for &UsbInterfaceDescriptorwhere
D: ResourceDialect,
impl Eq for UsbInterfaceDescriptor
Sourceimpl Hash for UsbInterfaceDescriptor
impl Hash for UsbInterfaceDescriptor
Sourceimpl Ord for UsbInterfaceDescriptor
impl Ord for UsbInterfaceDescriptor
Sourcefn cmp(&self, other: &UsbInterfaceDescriptor) -> Ordering
fn cmp(&self, other: &UsbInterfaceDescriptor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbInterfaceDescriptor
impl PartialEq for UsbInterfaceDescriptor
Sourcefn eq(&self, other: &UsbInterfaceDescriptor) -> bool
fn eq(&self, other: &UsbInterfaceDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbInterfaceDescriptor
impl PartialOrd for UsbInterfaceDescriptor
impl Persistable for UsbInterfaceDescriptor
impl StructuralPartialEq for UsbInterfaceDescriptor
Sourceimpl TypeMarker for UsbInterfaceDescriptor
impl TypeMarker for UsbInterfaceDescriptor
Sourcetype Owned = UsbInterfaceDescriptor
type Owned = UsbInterfaceDescriptor
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbInterfaceDescriptor
impl ValueTypeMarker for UsbInterfaceDescriptor
Sourcetype Borrowed<'a> = &'a UsbInterfaceDescriptor
type Borrowed<'a> = &'a UsbInterfaceDescriptor
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<UsbInterfaceDescriptor as TypeMarker>::Owned,
) -> <UsbInterfaceDescriptor as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<UsbInterfaceDescriptor as TypeMarker>::Owned, ) -> <UsbInterfaceDescriptor as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for UsbInterfaceDescriptor
impl RefUnwindSafe for UsbInterfaceDescriptor
impl Send for UsbInterfaceDescriptor
impl Sync for UsbInterfaceDescriptor
impl Unpin for UsbInterfaceDescriptor
impl UnsafeUnpin for UsbInterfaceDescriptor
impl UnwindSafe for UsbInterfaceDescriptor