#[repr(C)]pub struct UsbPortStatus {
pub w_port_status: u16,
pub w_port_change: u16,
}Fields
w_port_status: u16w_port_change: u16Trait Implementations
Sourceimpl Clone for UsbPortStatus
impl Clone for UsbPortStatus
Sourcefn clone(&self) -> UsbPortStatus
fn clone(&self) -> UsbPortStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbPortStatus
Sourceimpl Debug for UsbPortStatus
impl Debug for UsbPortStatus
Sourceimpl<D> Decode<UsbPortStatus, D> for UsbPortStatuswhere
D: ResourceDialect,
impl<D> Decode<UsbPortStatus, D> for UsbPortStatuswhere
D: ResourceDialect,
Sourcefn new_empty() -> UsbPortStatus
fn new_empty() -> UsbPortStatus
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<UsbPortStatus, D> for &UsbPortStatuswhere
D: ResourceDialect,
impl<D> Encode<UsbPortStatus, D> for &UsbPortStatuswhere
D: ResourceDialect,
impl Eq for UsbPortStatus
Sourceimpl Hash for UsbPortStatus
impl Hash for UsbPortStatus
Sourceimpl Ord for UsbPortStatus
impl Ord for UsbPortStatus
Sourcefn cmp(&self, other: &UsbPortStatus) -> Ordering
fn cmp(&self, other: &UsbPortStatus) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbPortStatus
impl PartialEq for UsbPortStatus
Sourcefn eq(&self, other: &UsbPortStatus) -> bool
fn eq(&self, other: &UsbPortStatus) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbPortStatus
impl PartialOrd for UsbPortStatus
impl Persistable for UsbPortStatus
impl StructuralPartialEq for UsbPortStatus
Sourceimpl TypeMarker for UsbPortStatus
impl TypeMarker for UsbPortStatus
Sourcetype Owned = UsbPortStatus
type Owned = UsbPortStatus
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbPortStatus
impl ValueTypeMarker for UsbPortStatus
Sourcetype Borrowed<'a> = &'a UsbPortStatus
type Borrowed<'a> = &'a UsbPortStatus
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<UsbPortStatus as TypeMarker>::Owned,
) -> <UsbPortStatus as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<UsbPortStatus as TypeMarker>::Owned, ) -> <UsbPortStatus as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for UsbPortStatus
impl RefUnwindSafe for UsbPortStatus
impl Send for UsbPortStatus
impl Sync for UsbPortStatus
impl Unpin for UsbPortStatus
impl UnsafeUnpin for UsbPortStatus
impl UnwindSafe for UsbPortStatus