#[repr(C)]pub struct UsbSetup {
pub bm_request_type: u8,
pub b_request: u8,
pub w_value: u16,
pub w_index: u16,
pub w_length: u16,
}Fields
bm_request_type: u8b_request: u8w_value: u16w_index: u16w_length: u16Trait Implementations
impl Copy for UsbSetup
Sourceimpl<D> Decode<UsbSetup, D> for UsbSetupwhere
D: ResourceDialect,
impl<D> Decode<UsbSetup, D> for UsbSetupwhere
D: ResourceDialect,
impl Eq for UsbSetup
Sourceimpl Ord for UsbSetup
impl Ord for UsbSetup
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for UsbSetup
impl PartialOrd for UsbSetup
impl Persistable for UsbSetup
impl StructuralPartialEq for UsbSetup
Sourceimpl TypeMarker for UsbSetup
impl TypeMarker for UsbSetup
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbSetup
impl ValueTypeMarker for UsbSetup
Sourcetype Borrowed<'a> = &'a UsbSetup
type Borrowed<'a> = &'a UsbSetup
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<UsbSetup as TypeMarker>::Owned,
) -> <UsbSetup as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<UsbSetup as TypeMarker>::Owned, ) -> <UsbSetup as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for UsbSetup
impl RefUnwindSafe for UsbSetup
impl Send for UsbSetup
impl Sync for UsbSetup
impl Unpin for UsbSetup
impl UnsafeUnpin for UsbSetup
impl UnwindSafe for UsbSetup